pub struct Linear { /* private fields */ }Expand description
Linear function structure
Implementations
Sourceimpl Linear
impl Linear
Sourcepub fn new(k: f64, b: f64, limit_a: f64, limit_b: f64) -> Linear
pub fn new(k: f64, b: f64, limit_a: f64, limit_b: f64) -> Linear
To create an object of function you need to use “new” method. After passing all the coefficients of the function, you need to pass the limits on which this function will exist
Sourcepub fn set_limits(&mut self, limit_a: f64, limit_b: f64)
pub fn set_limits(&mut self, limit_a: f64, limit_b: f64)
Function “set_limits” is used to change the limits on which your function will exist